import { RouteOptions } from "fastify";

import MercuryDataSource from "~/db/index.js";
import { Blog } from "~/db/entities/blog.js";
import { IsNull } from "typeorm";
import { blogToActivityPub } from "~/ap/blog.js";

const route: RouteOptions = {
  method: "GET",
  url: "/blogs/:username",
  handler: async (req, res) => {
    const username = (req.params as { username: string }).username;

    // Only respond to ActivityPub requests
    if (req.headers.accept && !req.headers.accept.indexOf("application/json")) {
      res.redirect(303, `/@${username}`);
    }

    const blog = await MercuryDataSource.getRepository(Blog).findOneBy({
      username,
      host: IsNull(),
    });
    if (!blog) {
      return res.status(404).send({ message: "Not found" });
    }

    return res.send(blogToActivityPub(blog));
  },
};

export default route;
